| Title: | R Client for WOS Lite API |
|---|---|
| Description: | R Client for the WOS Lite API. |
| Authors: | Nicolas Casajus [aut, cre, cph] (ORCID: <https://orcid.org/0000-0002-5537-5294>), Nicolas Mouquet [aut] (ORCID: <https://orcid.org/0000-0003-1840-6984>) |
| Maintainer: | Nicolas Casajus <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.1 |
| Built: | 2026-05-18 06:36:58 UTC |
| Source: | https://github.com/FRBCesab/rwoslite |
This function sends a query to the Web Of Science Lite API (https://developer.clarivate.com/apis/woslite) and returns references that match this query.
To learn how to write a WOS query, users can read the WOS documentation available at: https://images.webofknowledge.com/images/help/WOK/contents.html. A list of WOS field tags is available at: https://images.webofknowledge.com/images/help/WOS/hs_wos_fieldtags.html.
It's strongly recommended to use the function wos_search before to have an idea on how many records you will download.
Important: Due to WOS LITE API limitations, the total number of records cannot exceed 100,000.
wos_get_records(query, database = "WOS", limit = NULL, sleep = 1)wos_get_records(query, database = "WOS", limit = NULL, sleep = 1)
query |
a |
database |
a |
limit |
an |
sleep |
an |
A data.frame with n rows (where n is the total number of
references) and the following 21 variables:
ut: the unique identifier of the reference in the Web of Science system;
doc_type: the document type;
title: the title of the reference;
authors: the authors of the reference;
book_authors: the book authors (if applicable);
book_group_authors: the book group authors (if applicable);
keywords: the authors keywords;
source: the title of the source (journal, book, etc.) in which the
reference was published;
volume: the volume number;
issue: the issue number;
pages: the pages range in the source;
no_article: the article number;
published_date: the published date;
published_year: the published year;
supplement_number: the supplement number (if applicable);
special_issue: SI in case of a special issue (if applicable);
book_series_title: the book series title (if applicable);
doi: the Digital Object Identifier;
eissn: the Electronic International Standard Identifier Number;
issn: the International Standard Identifier Number;
isbn: International Standard Book Number.
## Not run: ## Download references of one author ---- query <- "AU=(\"Casajus N\")" wos_search(query) refs <- wos_get_records(query) refs <- wos_get_records(query, limit = 1) ## End(Not run)## Not run: ## Download references of one author ---- query <- "AU=(\"Casajus N\")" wos_search(query) refs <- wos_get_records(query) refs <- wos_get_records(query, limit = 1) ## End(Not run)
This function sends a query to the Web Of Science Lite API (https://developer.clarivate.com/apis/woslite) and returns the total number of records that match this query.
To learn how to write a WOS query, users can read the WOS documentation available at: https://images.webofknowledge.com/images/help/WOK/contents.html. A list of WOS field tags is available at: https://images.webofknowledge.com/images/help/WOS/hs_wos_fieldtags.html.
wos_search(query, database = "WOS")wos_search(query, database = "WOS")
query |
a |
database |
a |
The total number of records (integer of length 1) that match the
query.
## Not run: ## Search in TOPIC an exact expression ---- query <- "TS=\"salmo salar\"" wos_search(query) ## Search in TOPIC an exact expression and another term ---- query <- "TS=(\"salmo salar\" AND conservation)" wos_search(query) ## Search for a specific year ---- query <- "TS=(\"salmo salar\" AND conservation) AND PY=2021" wos_search(query) ## Search for a time span ---- query <- "TS=(\"salmo salar\" AND conservation) AND PY=2010-2021" wos_search(query) ## Search for an author ---- query <- "AU=(\"Casajus N\")" wos_search(query) ## End(Not run)## Not run: ## Search in TOPIC an exact expression ---- query <- "TS=\"salmo salar\"" wos_search(query) ## Search in TOPIC an exact expression and another term ---- query <- "TS=(\"salmo salar\" AND conservation)" wos_search(query) ## Search for a specific year ---- query <- "TS=(\"salmo salar\" AND conservation) AND PY=2021" wos_search(query) ## Search for a time span ---- query <- "TS=(\"salmo salar\" AND conservation) AND PY=2010-2021" wos_search(query) ## Search for an author ---- query <- "AU=(\"Casajus N\")" wos_search(query) ## End(Not run)